@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright © 2012 - 2020 Michal Čihař <michal@cihar.com>
 #
@@ -19,9 +18,8 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
 """Transifex configuration discovery."""
-from __future__ import absolute_import, unicode_literals
 
-from six.moves.configparser import RawConfigParser
+from configparser import RawConfigParser
 
 from .base import BaseDiscovery
 
@@ -52,26 +50,6 @@ class TransifexDiscovery(BaseDiscovery):
         "YML": "ruby-yaml",
     }
 
-    extension_map = (
-        (".po", "po"),
-        ("strings.xml", "aresource"),
-        (".ini", "joomla"),
-        (".csv", "csv"),
-        (".json", "json-nested"),
-        (".dtd", "dtd"),
-        (".php", "php"),
-        (".xlf", "xliff"),
-        (".xliff", "xliff"),
-        (".ts", "ts"),
-        (".resx", "resx"),
-        (".resw", "resx"),
-        (".xlsx", "xlsx"),
-        (".yml", "yaml"),
-        (".yaml", "yaml"),
-        (".properties", "properties"),
-        (".strings", "strings"),
-    )
-
     def extract_format(self, transifex):
         transifex = transifex.upper()
         try:
@@ -79,13 +57,6 @@ class TransifexDiscovery(BaseDiscovery):
         except KeyError:
             return ""
 
-    def detect_format(self, filemask):
-        filemask = filemask.lower()
-        for end, result in self.extension_map:
-            if filemask.endswith(end):
-                return result
-        return ""
-
     def extract_section(self, config, section):
         if section == "main" or not config.has_option(section, "file_filter"):
             return None
@@ -117,7 +88,7 @@ class TransifexDiscovery(BaseDiscovery):
         for path in self.finder.filter_files("config", ".tx"):
             config = RawConfigParser()
             with self.finder.open(path) as handle:
-                config.readfp(handle)
+                config.read_file(handle)
             for section in config.sections():
                 result = self.extract_section(config, section)
                 if result:
