@@ -79,6 +79,11 @@ class APITest(DiscoveryTestCase):
                     "filemask": "json/nested-*.json",
                     "template": "json/nested-en.json",
                 },
+                {
+                    "file_format": "go-i18n-json",
+                    "filemask": "json/go-*.json",
+                    "template": "json/go-en.json",
+                },
                 {
                     "file_format": "webextension",
                     "filemask": "json/webext-*.json",
