@@ -309,6 +309,176 @@ class GetttetTest(DiscoveryTestCase):
             ],
         )
 
+    def test_po_many(self):
+        with open(os.path.join(TEST_DATA, "calibre.txt"), "r") as handle:
+            filenames = handle.read().splitlines()
+        discovery = GettextDiscovery(self.get_finder(filenames))
+        self.assert_discovery(
+            discovery.discover(),
+            [
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/catalogs.po",
+                    "new_base": "translations/manual/catalogs.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/conversion.po",
+                    "new_base": "translations/manual/conversion.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/creating_plugins.po",
+                    "new_base": "translations/manual/creating_plugins.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/customize.po",
+                    "new_base": "translations/manual/customize.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/db_api.po",
+                    "new_base": "translations/manual/db_api.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/develop.po",
+                    "new_base": "translations/manual/develop.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/diff.po",
+                    "new_base": "translations/manual/diff.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/drm.po",
+                    "new_base": "translations/manual/drm.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/edit.po",
+                    "new_base": "translations/manual/edit.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/faq.po",
+                    "new_base": "translations/manual/faq.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/function_mode.po",
+                    "new_base": "translations/manual/function_mode.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/glossary.po",
+                    "new_base": "translations/manual/glossary.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/gui.po",
+                    "new_base": "translations/manual/gui.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/index.po",
+                    "new_base": "translations/manual/index.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/metadata.po",
+                    "new_base": "translations/manual/metadata.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/news.po",
+                    "new_base": "translations/manual/news.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/news_recipe.po",
+                    "new_base": "translations/manual/news_recipe.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/plugins.po",
+                    "new_base": "translations/manual/plugins.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/polish.po",
+                    "new_base": "translations/manual/polish.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/regexp.po",
+                    "new_base": "translations/manual/regexp.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/regexp_quick_reference.po",
+                    "new_base": "translations/manual/regexp_quick_reference.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/server.po",
+                    "new_base": "translations/manual/server.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/simple_index.po",
+                    "new_base": "translations/manual/simple_index.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/snippets.po",
+                    "new_base": "translations/manual/snippets.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/sphinx.po",
+                    "new_base": "translations/manual/sphinx.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/sub_groups.po",
+                    "new_base": "translations/manual/sub_groups.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/template_lang.po",
+                    "new_base": "translations/manual/template_lang.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/tutorials.po",
+                    "new_base": "translations/manual/tutorials.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/typesetting_math.po",
+                    "new_base": "translations/manual/typesetting_math.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/viewer.po",
+                    "new_base": "translations/manual/viewer.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/virtual_libraries.po",
+                    "new_base": "translations/manual/virtual_libraries.pot",
+                },
+                {
+                    "file_format": "po",
+                    "filemask": "translations/manual/*/xpath.po",
+                    "new_base": "translations/manual/xpath.pot",
+                },
+            ],
+        )
+
 
 class QtTest(DiscoveryTestCase):
     def test_basic(self):
@@ -317,10 +487,10 @@ class QtTest(DiscoveryTestCase):
                 [
                     "ts/cs.ts",
                     "ts/zh_CN.ts",
+                    "lrc/translations/lrc_de.ts",
                     "lrc/translations/lrc_id.ts",
                     "quickevent/app/quickevent/quickevent.cs_CZ.ts",
                     "libqf/libqfqmlwidgets/libqfqmlwidgets.pl_PL.ts",
-                    "6-migrate-archived-model-to-revision.ts",
                 ]
             )
         )
@@ -331,7 +501,7 @@ class QtTest(DiscoveryTestCase):
                 {
                     "filemask": "lrc/translations/lrc_*.ts",
                     "file_format": "ts",
-                    "new_base": "lrc/translations/lrc_id.ts",
+                    "new_base": "lrc/translations/lrc_de.ts",
                 },
                 {
                     "filemask": "quickevent/app/quickevent/quickevent.*.ts",
@@ -343,10 +513,6 @@ class QtTest(DiscoveryTestCase):
                     "file_format": "ts",
                     "new_base": "libqf/libqfqmlwidgets/libqfqmlwidgets.pl_PL.ts",
                 },
-                {
-                    "filemask": "6-migrate-archived-model-*-revision.ts",
-                    "file_format": "ts",
-                },
             ],
         )
 
@@ -390,12 +556,12 @@ class OSXTest(DiscoveryTestCase):
             [
                 {
                     "filemask": "App/Resources/*.lproj/Localizable.strings",
-                    "file_format": "strings",
+                    "file_format": "strings-utf8",
                     "template": "App/Resources/en.lproj/Localizable.strings",
                 },
                 {
                     "filemask": "App/Resources/*.lproj/Other.strings",
-                    "file_format": "strings",
+                    "file_format": "strings-utf8",
                     "template": "App/Resources/Base.lproj/Other.strings",
                 },
             ],
@@ -418,6 +584,8 @@ class JavaTest(DiscoveryTestCase):
                     "bundle/Other_Messages.properties",
                     "length_1.properties",
                     "length_1_de.properties",
+                    "foo_en.properties",
+                    "foo_de.properties",
                 ]
             )
         )
@@ -434,6 +602,11 @@ class JavaTest(DiscoveryTestCase):
                     "file_format": "properties",
                     "template": "length_1.properties",
                 },
+                {
+                    "file_format": "properties",
+                    "filemask": "foo_*.properties",
+                    "template": "foo_en.properties",
+                },
             ],
         )
 
@@ -614,6 +787,138 @@ class JSONDiscoveryTest(DiscoveryTestCase):
             ],
         )
 
+    def test_json_data(self):
+        """
+        Test discovery on huge list of JSON files.
+
+        Based on Cataclysm-DDA, see
+        https://github.com/WeblateOrg/translation-finder/issues/54
+        """
+        with open(os.path.join(TEST_DATA, "catalysm.txt"), "r") as handle:
+            filenames = handle.read().splitlines()
+        discovery = JSONDiscovery(self.get_finder(filenames))
+        # This has many false positives, but most of them come from
+        # filename starting with language code what is something we generally want
+        # to detect
+        self.assert_discovery(
+            discovery.discover(),
+            [
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/mapgen/*_car_dealership.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/mapgen/*_car_showroom.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/mapgen/*_city_dump_small.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/mapgen/*_gardening_allotment.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/mapgen/*_internet_cafe.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/mapgen/*_market_small.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/mapgen/*_open_sewer_small.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/mapgen/*_private_park.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/mapgen/*_public_art_piece.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/mapgen/*_public_space.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/mapgen/*_sex_shop.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/mapgen/*_tire_shop.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/mapgen/house/house05_*.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/mapgen/mi-go/*-go_encampment.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/mapgen/mi-go/*-go_nested.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/mapgen/mi-go/*-go_scout_tower.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/mapgen/refugee_center/rc_grounds_*.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/mapgen_palettes/*-go_palette.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/monstergroups/*-go.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/monsters/*-go.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/npcs/*_trait_groups.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/npcs/*_traits.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/npcs/holdouts/*_Lapin.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/json/npcs/prisoners/*-go_prisoners.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/mods/more_classes_scenarios/*_classes.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/mods/more_classes_scenarios/*_scenarios.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/mods/more_classes_scenarios/*_locations.json",
+                },
+                {
+                    "file_format": "json-nested",
+                    "filemask": "data/names/*.json",
+                    "template": "data/names/en.json",
+                },
+            ],
+        )
+
 
 class TransifexTest(DiscoveryTestCase):
     def test_basic(self):
@@ -722,6 +1027,18 @@ class YAMLDiscoveryTest(DiscoveryTestCase):
             ],
         )
 
+    def test_workflows(self):
+        discovery = YAMLDiscovery(
+            self.get_finder(
+                [
+                    ".github/workflows/json.yml",
+                    ".github/workflows/pr-validator.yml",
+                    ".github/workflows/ccpp.yml",
+                ]
+            )
+        )
+        self.assert_discovery(discovery.discover(), [])
+
 
 class TOMLDiscoveryTest(DiscoveryTestCase):
     def test_basic(self):
